# butterfly-themes
Repository for butterfly themes

## Usage

With an up to date butterfly 2.0 installation, clone this repository in your butterfly config like this:

```bash
$ cd .butterfly
$ git clone https://github.com/paradoxxxzero/butterfly-themes.git themes
```

and then start your server with `--theme=C64` for example.

## Submit your styles

I'll gladly accept any pull request featuring a style !
